/**
 * NORRIS.js
 * Copyright (c) 2011 Ruben L Z Tan
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS 
 * IN THE SOFTWARE.
 */
'use strict';

/**
 * Norris Namespace
 * 
 *  Norris
 *      - Common
 *          - Str           String utilities
 *          - Util          Common utilities
 *      - Data
 *          - Driver
 *              - Couch     CouchDB driver
 *              - Redis     Redis driver
 *          - Cache         Cache
 *          - Session       Session
 *          - Dao           Data Accessor Object (CRUD)
 *      - Hook
 *          - Twitter       Twitter driver
 *          - Facebook      Facebook driver
 *          - Dropbox       Dropbox driver
 *          - Flickr        Flickr driver
 *      - Core
 *          - Socket        Socket manager
 *          - Server        Server manager
 */

var Factory = require(__dirname + '/factory')

var Norris = Factory.init({
    Common : {
        Str : null,
        Util : null
    },
    Data : {
        Driver : {
            Couch : null,
            Redis : null,
            Mysql : null
        },
        Cache : null,
        Session : null,
        Dao : null
    },
    Hook : {
        Twitter : null,
        Facebook : null,
        Dropbox : null,
        Flickr : null
    },
    Core : {
        Socket : null,
        Server : null
    }
})

module.exports = Norris
