/**
 * NORRIS.js
 * Copyright (c) 2011 Ruben L Z Tan
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS 
 * IN THE SOFTWARE.
 */
'use strict';

var fs      = require('fs');
var path    = require('path');
var Emitter = require('events').EventEmitter;
var exec    = require('child_process').exec;

var vows    = require('vows');
var assert  = require('assert');

var Test = module.exports = {
    // Properties
    types   : ['all', 'unit', 'http', 'full'],
    options : ['p', 'pass-only', 'f', 'fail-only', 'v', 'verbose', 'h', 'help'],
    
    // Methods
    run     : run
};

/**----------------------------------------------------------------------------
 * Runs the command
 */
function run(util, commands, options) {
    var self = this;
    var type = commands[0];
    
    // Check if the test that we want to run is a supported type or just a 
    // list of unit test files
    if (!type || -1 !== self.types.indexOf(type)) {
        type = (null == type) ? 'all' : type;
    }
    // Not a supported type. Treat it as a namespace to a file 
    else {
        type = [];
        for (var i = commands.length; i--;) {
            var cmd = commands[i];
            type[cmd.replace(/\.g/g, '/') + '.js'] = true;
        }
    }
    
    // Check if there are unsupported options
    var unsupported = util.options(self.options).input(options).check();
    if (unsupported.length > 0) {
        util.color('#red[Unsupported options %s\n]', unsupported.join(', '));
        util.help('test');
        return;
    }
    
    // Options
    var passOnly    = util.has('p', 'pass-only');
    var failOnly    = util.has('f', 'fail-only');
    var verbode     = util.has('v', 'verbode');
    var help        = util.has('h', 'help');
    
    if (help) {
        util.help('test');
        return;
    }
    
    var promise = new Emitter();
    
    // Handle errors when running the test cases
    promise.on('error', function onErr(err) {
        util.log('Unexpected error encountered');
        util.log(err.stack);
    });
    
    // Handle file event
    promise.on('file', function onFile(path, name) {
        var test = require(path).make();
        console.log(test.run());
    });
    
    // Try executing a test suite
    
}
